pub struct OperationRecord<'a> {
pub offset: usize,
pub bytes: &'a [u8],
pub payload_offset: usize,
pub payload: &'a [u8],
pub label: OperationLabel<'a>,
}Expand description
One operation record bounded by consecutive validated operation headers.
Fields
offset: usizeAbsolute offset of the fixed operation-header marker.
bytes: &'a [u8]Complete record bytes through the next operation header or section end.
payload_offset: usizeAbsolute offset of the first byte after the operation-label terminator.
payload: &'a [u8]Post-label serialized operation payload.
label: OperationLabel<'a>Label decoded from this record’s header.