pub struct Section<'a> {
pub offset: usize,
pub byte_len: usize,
pub types: Vec<TypeDefinition<'a>>,
pub fields: Vec<FieldDefinition<'a>>,
pub record_area_offset: Option<usize>,
pub record_area: Option<&'a [u8]>,
}Expand description
One size-framed NX object-model section.
Fields
offset: usizeOffset of the ff ff ff ff section signature.
byte_len: usizeComplete section length including its 16-byte header.
types: Vec<TypeDefinition<'a>>Class declarations in the section’s contiguous type registry.
fields: Vec<FieldDefinition<'a>>Member declarations in the section’s field registry.
record_area_offset: Option<usize>Absolute offset of the section’s internally pointed record area.
record_area: Option<&'a [u8]>Exact record-area bytes, including its 12-byte control prefix.
Implementations
Sourceimpl<'a> Section<'a>
impl<'a> Section<'a>
Sourcepub fn record_area_header(&self) -> Option<RecordAreaHeader<'a>>
pub fn record_area_header(&self) -> Option<RecordAreaHeader<'a>>
Decode the validated record-area control and product header.
Sourcepub fn operation_labels(&self) -> Vec<OperationLabel<'a>>
pub fn operation_labels(&self) -> Vec<OperationLabel<'a>>
Decode strictly framed operation labels from the pointed record area.
Sourcepub fn boolean_operations(&self) -> Vec<BooleanOperation>
pub fn boolean_operations(&self) -> Vec<BooleanOperation>
Decode fully framed Boolean operations from the pointed record area.
Sourcepub fn operation_records(&self) -> Vec<OperationRecord<'a>>
pub fn operation_records(&self) -> Vec<OperationRecord<'a>>
Bound operation records by consecutive validated operation headers.
Sourcepub fn operation_records_with_label_ordinals(
&self,
) -> Vec<(usize, OperationRecord<'a>)>
pub fn operation_records_with_label_ordinals( &self, ) -> Vec<(usize, OperationRecord<'a>)>
Bound operation records and retain their ordinal in the complete label sequence.
Sourcepub fn operation_body_references(&self) -> Vec<(usize, OperationBodyReference)>
pub fn operation_body_references(&self) -> Vec<(usize, OperationBodyReference)>
Decode unambiguous primary body references from bounded operation records.