Section

Struct Section 

pub struct Section<'a> {
    pub offset: usize,
    pub byte_len: usize,
    pub types: Vec<TypeDefinition<'a>>,
    pub fields: Vec<FieldDefinition<'a>>,
    pub record_area_offset: Option<usize>,
    pub record_area: Option<&'a [u8]>,
}
One size-framed NX object-model section.

Fields

offset: usize

Offset of the ff ff ff ff section signature.

byte_len: usize

Complete section length including its 16-byte header.

types: Vec<TypeDefinition<'a>>

Class declarations in the section’s contiguous type registry.

fields: Vec<FieldDefinition<'a>>

Member declarations in the section’s field registry.

record_area_offset: Option<usize>

Absolute offset of the section’s internally pointed record area.

record_area: Option<&'a [u8]>

Exact record-area bytes, including its 12-byte control prefix.

Implementations

Source

impl<'a> Section<'a>

pub fn record_area_header(&self) -> Option<RecordAreaHeader<'a>>

Decode the validated record-area control and product header.

pub fn operation_labels(&self) -> Vec<OperationLabel<'a>>

Decode strictly framed operation labels from the pointed record area.

pub fn boolean_operations(&self) -> Vec<BooleanOperation>

Decode fully framed Boolean operations from the pointed record area.

pub fn operation_records(&self) -> Vec<OperationRecord<'a>>

Bound operation records by consecutive validated operation headers.

pub fn operation_records_with_label_ordinals( &self, ) -> Vec<(usize, OperationRecord<'a>)>

Bound operation records and retain their ordinal in the complete label sequence.

pub fn operation_body_references(&self) -> Vec<(usize, OperationBodyReference)>

Decode unambiguous primary body references from bounded operation records.